Skip to content

Instantly share code, notes, and snippets.

@samm-git
Created June 20, 2015 16:40
Show Gist options
  • Save samm-git/a9617b805b9271133234 to your computer and use it in GitHub Desktop.
Save samm-git/a9617b805b9271133234 to your computer and use it in GitHub Desktop.
Index: os_freebsd.cpp
===================================================================
--- os_freebsd.cpp (revision 4110)
+++ os_freebsd.cpp (working copy)
@@ -959,8 +959,8 @@
return set_err(ENOMEM);
}
- // mfi SAT layer is known to be buggy
- if(!strcmp("mfi",m_camdev->sim_name)) {
+ // mfi and mrsas SAT layers are known to be buggy
+ if(!strcmp("mfi",m_camdev->sim_name) || !strcmp("mrsas",m_camdev->sim_name)) {
if (iop->cmnd[0] == SAT_ATA_PASSTHROUGH_12 || iop->cmnd[0] == SAT_ATA_PASSTHROUGH_16) {
// Controller does not return ATA output registers in SAT sense data
if (iop->cmnd[2] & (1 << 5)) // chk_cond
@@ -1318,12 +1318,12 @@
return this;
}
- // SAT or USB, skip MFI controllers because of bugs
+ // SAT or USB, skip LSI controllers because of bugs
{
smart_device * newdev = smi()->autodetect_sat_device(this, req_buff, len);
if (newdev) {
// NOTE: 'this' is now owned by '*newdev'
- if(!strcmp("mfi",m_camdev->sim_name)) {
+ if(!strcmp("mfi",m_camdev->sim_name) || !strcmp("mrsas", m_camdev->sim_name)) {
newdev->close();
newdev->set_err(ENOSYS, "SATA device detected,\n"
"MegaRAID SAT layer is reportedly buggy, use '-d sat' to try anyhow");
Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment